@@ -14,26 +14,33 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __PYGI_BOXED_H__
 #define __PYGI_BOXED_H__
 
-#include <Python.h>
+#include <girepository/girepository.h>
+#include <pythoncapi_compat.h>
+
+#include "pygobject-internal.h"
 
 G_BEGIN_DECLS
 
+typedef struct _PyGIBoxed PyGIBoxed;
+
 extern PyTypeObject PyGIBoxed_Type;
 
-PyObject *
-_pygi_boxed_new (PyTypeObject *type,
-                 gpointer      boxed,
-                 gboolean      free_on_dealloc);
+PyObject * pygi_boxed_new (PyTypeObject *type,
+                           gpointer      boxed,
+                           gboolean      free_on_dealloc,
+                           gsize         allocated_slice);
 
-void _pygi_boxed_register_types (PyObject *m);
+void * pygi_boxed_alloc (GIBaseInfo *info, gsize *size);
+
+void pygi_boxed_copy_in_place  (PyGIBoxed *self);
+
+int pygi_boxed_register_types (PyObject *m);
 
 G_END_DECLS
 
