@@ -25,24 +25,32 @@
 #ifndef __PYGI_FOREIGN_H__
 #define __PYGI_FOREIGN_H__
 
-#include <Python.h>
-#include <girepository.h>
+#include <pythoncapi_compat.h>
 
-#include "pygi.h"
+#include "pygi-foreign-api.h"
 
 PyObject *pygi_struct_foreign_convert_to_g_argument (PyObject           *value,
-                                                     GITypeInfo         *type_info,
+                                                     GIRegisteredTypeInfo *interface_info,
                                                      GITransfer          transfer,
-                                                     GIArgument          *arg);
-PyObject *pygi_struct_foreign_convert_from_g_argument (GITypeInfo *type_info,
-                                                       GIArgument  *arg);
-PyObject *pygi_struct_foreign_release (GITypeInfo *type_info,
+                                                     GIArgument         *arg);
+PyObject *pygi_struct_foreign_convert_from_g_argument (GIRegisteredTypeInfo *interface_info,
+                                                       GITransfer       transfer,
+                                                       GIArgument      *arg);
+PyObject *pygi_struct_foreign_release (GIBaseInfo *base_info,
                                        gpointer struct_);
 
-void pygi_register_foreign_struct_real (const char* namespace_,
-                                        const char* name,
-                                        PyGIArgOverrideToGIArgumentFunc to_func,
-                                        PyGIArgOverrideFromGIArgumentFunc from_func,
-                                        PyGIArgOverrideReleaseFunc release_func);
+void pygi_register_foreign_struct (const char* namespace_,
+                                   const char* name,
+                                   PyGIArgOverrideToGIArgumentFunc to_func,
+                                   PyGIArgOverrideFromGIArgumentFunc from_func,
+                                   PyGIArgOverrideReleaseFunc release_func);
+
+PyObject *pygi_require_foreign    (PyObject *self,
+                                   PyObject *args,
+                                   PyObject *kwargs);
+
+int pygi_foreign_init (void);
+
+PyObject *pygi_register_foreign (PyObject *self, PyObject *args);
 
 #endif /* __PYGI_FOREIGN_H__ */
